@@ -111,7 +111,7 @@ let ChangeForm = {
       if (cur.length) {
         let url = cur.attr('href')
         let ext = url.split('.').pop()
-        if (['jpg', 'jpeg', 'png', 'bmp', 'svg', 'gif', 'tif'].indexOf(ext) !== -1) {
+        if (['jpg', 'jpeg', 'png', 'bmp', 'svg', 'gif', 'tif', 'webp'].indexOf(ext) !== -1) {
           let spinner = $('<i />', {'class': 'fa fa-spinner fa-spin fa-2x fa-fw'}).css('color', '#aaa')
           let preview = $('<div />', {'class': 'py-2'}).append(spinner)
           $(p).prepend(preview)
